==> react-lds-8.7.0.tgz: package/es/components/Images/Avatar.js <==
import "core-js/modules/es7.symbol.async-iterator";
import "core-js/modules/es6.object.assign";
import "core-js/modules/es6.symbol";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.to-string";
import "core-js/modules/es6.object.keys";
import "core-js/modules/es6.function.name";

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { isString, startCase, upperCase, words } from 'lodash-es';
import { Icon } from '../Icon';
export var BaseAvatar = function BaseAvatar(_ref) {
  var className = _ref.className,
      image = _ref.image,
      round = _ref.round,
      size = _ref.size,
      renderFallback = _ref.renderFallback,
      rest = _objectWithoutProperties(_ref, ["className", "image", "round", "size", "renderFallback"]);

  return React.createElement("span", _extends({}, rest, {
    className: cx(['slds-avatar', {
      'slds-avatar_circle': round
    }, _defineProperty({}, "slds-avatar_".concat(size), size), className])
  }), image || renderFallback());
};
BaseAvatar.defaultProps = {
  className: null,
  image: null,
  renderFallback: function renderFallback() {
    return null;
  },
  round: false,
  size: null
};
BaseAvatar.propTypes = process.env.NODE_ENV !== "production" ? {
  className: PropTypes.string,
  image: PropTypes.element,
  renderFallback: PropTypes.func,
  round: PropTypes.bool,
  size: PropTypes.oneOf(['x-small', 'small', 'medium', 'large'])
} : {};
export var getInitials = function getInitials() {
  var str = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  if (!isString(str) || str.length === 0) return '';
  var strWords = words(str);

  var _strWords = _slicedToArray(strWords, 2),
      first = _strWords[0],
      second = _strWords[1];

  if (!first) return '';
  if (!second) return startCase(first.substring(0, 2));
  return upperCase("".concat(first[0]).concat(second[0]));
};
export var EntityAvatar = function EntityAvatar(_ref3) {
  var displayType = _ref3.displayType,
      _ref3$icon = _ref3.icon,
      icon = _ref3$icon.icon,
      sprite = _ref3$icon.sprite,
      name = _ref3.name,
      rest = _objectWithoutProperties(_ref3, ["displayType", "icon", "name"]);

  var fallbackRenderer = displayType === 'icon' ? function () {
    return React.createElement(Icon, {
      icon: icon,
      sprite: sprite,
      title: name
    });
  } : function () {
    return React.createElement("abbr", {
      className: cx(['slds-avatar__initials', "slds-icon-".concat(sprite, "-").concat(icon)]),
      title: name
    }, getInitials(name));
  };
  return React.createElement(BaseAvatar, _extends({}, rest, {
    image: null,
    renderFallback: fallbackRenderer
  }));
};
EntityAvatar.defaultProps = {
  className: null,
  displayType: 'icon',
  size: null,
  title: null
};
EntityAvatar.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Additional classnames
   */
  className: PropTypes.string,

  /**
   * Display Types:
   * `icon`: icon set via `icon`
   * `initials`: initials (computed from `name`) in `icon` coloring
   */
  displayType: PropTypes.oneOf(['icon', 'initials']),

  /**
   * Combination of icon and sprite corresponding to the entity type
   */
  icon: PropTypes.shape({
    sprite: PropTypes.string.isRequired,
    icon: PropTypes.string.isRequired
  }).isRequired,

  /**
   * Entity name
   */
  name: PropTypes.string.isRequired,

  /**
   * Avatar size
   */
  size: PropTypes.oneOf(['x-small', 'small', 'medium', 'large']),

  /**
   * `title` attribute, defaults to the value of `name` if not set
   */
  title: PropTypes.string
} : {};
export var UserAvatar = function UserAvatar(_ref4) {
  var className = _ref4.className,
      fallbackType = _ref4.fallbackType,
      imageSrc = _ref4.imageSrc,
      name = _ref4.name,
      round = _ref4.round,
      title = _ref4.title,
      rest = _objectWithoutProperties(_ref4, ["className", "fallbackType", "imageSrc", "name", "round", "title"]);

  var tooltip = title || name;

  if (imageSrc) {
    return React.createElement(BaseAvatar, _extends({}, rest, {
      className: className,
      round: round,
      image: React.createElement("img", {
        src: imageSrc,
        alt: name,
        title: tooltip
      })
    }));
  }

  var sldsClasses = [{
    'slds-avatar_profile-image-large': fallbackType === 'profile-image'
  }, {
    'slds-avatar_group-image-large': fallbackType === 'group-image'
  }, className];
  var isCssImageFallback = fallbackType === 'profile-image' || fallbackType === 'group-image';
  var fallbackRenderer;

  if (isCssImageFallback) {
    fallbackRenderer = function fallbackRenderer() {
      return React.createElement("span", {
        className: "slds-assistive-text"
      }, name);
    };
  } else if (fallbackType === 'icon') {
    fallbackRenderer = function fallbackRenderer() {
      return React.createElement(Icon, {
        sprite: "standard",
        icon: "user",
        title: tooltip
      });
    };
  } else {
    var classes = ['slds-avatar__initials', {
      'slds-icon-standard-user': fallbackType === 'initials'
    }, {
      'slds-avatar__initials_inverse': fallbackType === 'initials-inverse'
    }];

    fallbackRenderer = function fallbackRenderer() {
      return React.createElement("abbr", {
        className: cx(classes),
        title: tooltip
      }, getInitials(name));
    };
  }

  return React.createElement(BaseAvatar, _extends({}, rest, {
    className: cx(sldsClasses),
    round: round || !isCssImageFallback,
    renderFallback: fallbackRenderer,
    title: isCssImageFallback ? tooltip : null
  }));
};
UserAvatar.defaultProps = {
  className: null,
  fallbackType: 'icon',
  imageSrc: null,
  round: false,
  size: null,
  title: null
};
UserAvatar.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Additional classnames
   */
  className: PropTypes.string,

  /**
   * Fallback Types:
   * `icon`: icon of the User object
   * `initials`: initials (computed from `name`) in User object standard coloring
   * `initials-inverse`: initials in inverse coloring
   * `profile-image`: LDS profile image placeholder
   * `group-image`: LDS group image placeholder
   */
  fallbackType: PropTypes.oneOf(['icon', 'initials', 'initials-inverse', 'profile-image', 'group-image']),

  /**
   * `src` attribute of the avatar image. If not set, a fallback of `fallbackType` will be rendered
   */
  imageSrc: PropTypes.string,

  /**
   * User Name or identifier
   */
  name: PropTypes.string.isRequired,

  /**
   * Renders as a round image / fallback
   */
  round: PropTypes.bool,

  /**
   * Avatar size
   */
  size: PropTypes.oneOf(['x-small', 'small', 'medium', 'large']),

  /**
   * `title` attribute, defaults to the value of `name` if not set
   */
  title: PropTypes.string
} : {}; // Deprecated

export var Avatar = function Avatar(props) {
  var alt = props.alt,
      circle = props.circle,
      className = props.className,
      src = props.src,
      size = props.size,
      title = props.title,
      rest = _objectWithoutProperties(props, ["alt", "circle", "className", "src", "size", "title"]);

  var sldsClasses = ['slds-avatar', _defineProperty({}, "slds-avatar_".concat(size), !!size), {
    'slds-avatar_empty': !src
  }, {
    'slds-avatar_circle': circle
  }, className];
  return React.createElement("span", _extends({}, rest, {
    className: cx(sldsClasses)
  }), src ? React.createElement("img", {
    src: src,
    alt: alt,
    title: title
  }) : null);
}; // Deprecated

Avatar.defaultProps = {
  alt: null,
  circle: false,
  className: null,
  size: null,
  src: null,
  title: null
}; // Deprecated

Avatar.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * img alt
   */
  alt: PropTypes.string,

  /**
   * renders a round avatar
   */
  circle: PropTypes.bool,

  /**
   * class name
   */
  className: PropTypes.string,

  /**
   * img src (prepended with context.assetBasePath)
   */
  src: PropTypes.string,

  /**
   * image size
   */
  size: PropTypes.oneOf(['x-small', 'small', 'medium', 'large']),

  /**
   * title
   */
  title: PropTypes.string
} : {};

==> react-lds-9.1.0.tgz: package/es/components/Images/Avatar.js <==
import "core-js/modules/es.symbol";
import "core-js/modules/es.symbol.description";
import "core-js/modules/es.symbol.iterator";
import "core-js/modules/es.array.concat";
import "core-js/modules/es.array.index-of";
import "core-js/modules/es.array.iterator";
import "core-js/modules/es.date.to-string";
import "core-js/modules/es.function.name";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.keys";
import "core-js/modules/es.object.to-string";
import "core-js/modules/es.regexp.to-string";
import "core-js/modules/es.string.iterator";
import "core-js/modules/web.dom-collections.iterator";

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) { return; } var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { isString, startCase, upperCase, words } from 'lodash-es';
import { Icon } from '../Icon';
export var BaseAvatar = function BaseAvatar(_ref) {
  var className = _ref.className,
      image = _ref.image,
      round = _ref.round,
      size = _ref.size,
      renderFallback = _ref.renderFallback,
      rest = _objectWithoutProperties(_ref, ["className", "image", "round", "size", "renderFallback"]);

  return React.createElement("span", _extends({}, rest, {
    className: cx(['slds-avatar', {
      'slds-avatar_circle': round
    }, _defineProperty({}, "slds-avatar_".concat(size), size), className])
  }), image || renderFallback());
};
BaseAvatar.defaultProps = {
  className: null,
  image: null,
  renderFallback: function renderFallback() {
    return null;
  },
  round: false,
  size: null
};
BaseAvatar.propTypes = process.env.NODE_ENV !== "production" ? {
  className: PropTypes.string,
  image: PropTypes.element,
  renderFallback: PropTypes.func,
  round: PropTypes.bool,
  size: PropTypes.oneOf(['x-small', 'small', 'medium', 'large'])
} : {};
export var getInitials = function getInitials() {
  var str = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  if (!isString(str) || str.length === 0) return '';
  var strWords = words(str);

  var _strWords = _slicedToArray(strWords, 2),
      first = _strWords[0],
      second = _strWords[1];

  if (!first) return '';
  if (!second) return startCase(first.substring(0, 2));
  return upperCase("".concat(first[0]).concat(second[0]));
};
export var EntityAvatar = function EntityAvatar(_ref3) {
  var displayType = _ref3.displayType,
      _ref3$icon = _ref3.icon,
      icon = _ref3$icon.icon,
      sprite = _ref3$icon.sprite,
      name = _ref3.name,
      rest = _objectWithoutProperties(_ref3, ["displayType", "icon", "name"]);

  var fallbackRenderer = displayType === 'icon' ? function () {
    return React.createElement(Icon, {
      icon: icon,
      sprite: sprite,
      title: name
    });
  } : function () {
    return React.createElement("abbr", {
      className: cx(['slds-avatar__initials', "slds-icon-".concat(sprite, "-").concat(icon)]),
      title: name
    }, getInitials(name));
  };
  return React.createElement(BaseAvatar, _extends({}, rest, {
    image: null,
    renderFallback: fallbackRenderer
  }));
};
EntityAvatar.defaultProps = {
  className: null,
  displayType: 'icon',
  size: null,
  title: null
};
EntityAvatar.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Additional classnames
   */
  className: PropTypes.string,

  /**
   * Display Types:
   * `icon`: icon set via `icon`
   * `initials`: initials (computed from `name`) in `icon` coloring
   */
  displayType: PropTypes.oneOf(['icon', 'initials']),

  /**
   * Combination of icon and sprite corresponding to the entity type
   */
  icon: PropTypes.shape({
    sprite: PropTypes.string.isRequired,
    icon: PropTypes.string.isRequired
  }).isRequired,

  /**
   * Entity name
   */
  name: PropTypes.string.isRequired,

  /**
   * Avatar size
   */
  size: PropTypes.oneOf(['x-small', 'small', 'medium', 'large']),

  /**
   * `title` attribute, defaults to the value of `name` if not set
   */
  title: PropTypes.string
} : {};
export var UserAvatar = function UserAvatar(_ref4) {
  var className = _ref4.className,
      fallbackType = _ref4.fallbackType,
      imageSrc = _ref4.imageSrc,
      name = _ref4.name,
      round = _ref4.round,
      title = _ref4.title,
      rest = _objectWithoutProperties(_ref4, ["className", "fallbackType", "imageSrc", "name", "round", "title"]);

  var tooltip = title || name;

  if (imageSrc) {
    return React.createElement(BaseAvatar, _extends({}, rest, {
      className: className,
      round: round,
      image: React.createElement("img", {
        src: imageSrc,
        alt: name,
        title: tooltip
      })
    }));
  }

  var sldsClasses = [{
    'slds-avatar_profile-image-large': fallbackType === 'profile-image'
  }, {
    'slds-avatar_group-image-large': fallbackType === 'group-image'
  }, className];
  var isCssImageFallback = fallbackType === 'profile-image' || fallbackType === 'group-image';
  var fallbackRenderer;

  if (isCssImageFallback) {
    fallbackRenderer = function fallbackRenderer() {
      return React.createElement("span", {
        className: "slds-assistive-text"
      }, name);
    };
  } else if (fallbackType === 'icon') {
    fallbackRenderer = function fallbackRenderer() {
      return React.createElement(Icon, {
        sprite: "standard",
        icon: "user",
        title: tooltip
      });
    };
  } else {
    var classes = ['slds-avatar__initials', {
      'slds-icon-standard-user': fallbackType === 'initials'
    }, {
      'slds-avatar__initials_inverse': fallbackType === 'initials-inverse'
    }];

    fallbackRenderer = function fallbackRenderer() {
      return React.createElement("abbr", {
        className: cx(classes),
        title: tooltip
      }, getInitials(name));
    };
  }

  return React.createElement(BaseAvatar, _extends({}, rest, {
    className: cx(sldsClasses),
    round: round || !isCssImageFallback,
    renderFallback: fallbackRenderer,
    title: isCssImageFallback ? tooltip : null
  }));
};
UserAvatar.defaultProps = {
  className: null,
  fallbackType: 'icon',
  imageSrc: null,
  round: false,
  size: null,
  title: null
};
UserAvatar.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * Additional classnames
   */
  className: PropTypes.string,

  /**
   * Fallback Types:
   * `icon`: icon of the User object
   * `initials`: initials (computed from `name`) in User object standard coloring
   * `initials-inverse`: initials in inverse coloring
   * `profile-image`: LDS profile image placeholder
   * `group-image`: LDS group image placeholder
   */
  fallbackType: PropTypes.oneOf(['icon', 'initials', 'initials-inverse', 'profile-image', 'group-image']),

  /**
   * `src` attribute of the avatar image. If not set, a fallback of `fallbackType` will be rendered
   */
  imageSrc: PropTypes.string,

  /**
   * User Name or identifier
   */
  name: PropTypes.string.isRequired,

  /**
   * Renders as a round image / fallback
   */
  round: PropTypes.bool,

  /**
   * Avatar size
   */
  size: PropTypes.oneOf(['x-small', 'small', 'medium', 'large']),

  /**
   * `title` attribute, defaults to the value of `name` if not set
   */
  title: PropTypes.string
} : {}; // Deprecated

export var Avatar = function Avatar(props) {
  var alt = props.alt,
      circle = props.circle,
      className = props.className,
      src = props.src,
      size = props.size,
      title = props.title,
      rest = _objectWithoutProperties(props, ["alt", "circle", "className", "src", "size", "title"]);

  var sldsClasses = ['slds-avatar', _defineProperty({}, "slds-avatar_".concat(size), !!size), {
    'slds-avatar_empty': !src
  }, {
    'slds-avatar_circle': circle
  }, className];
  return React.createElement("span", _extends({}, rest, {
    className: cx(sldsClasses)
  }), src ? React.createElement("img", {
    src: src,
    alt: alt,
    title: title
  }) : null);
}; // Deprecated

Avatar.defaultProps = {
  alt: null,
  circle: false,
  className: null,
  size: null,
  src: null,
  title: null
}; // Deprecated

Avatar.propTypes = process.env.NODE_ENV !== "production" ? {
  /**
   * img alt
   */
  alt: PropTypes.string,

  /**
   * renders a round avatar
   */
  circle: PropTypes.bool,

  /**
   * class name
   */
  className: PropTypes.string,

  /**
   * img src (prepended with context.assetBasePath)
   */
  src: PropTypes.string,

  /**
   * image size
   */
  size: PropTypes.oneOf(['x-small', 'small', 'medium', 'large']),

  /**
   * title
   */
  title: PropTypes.string
} : {};
